@@ -388,6 +388,43 @@ static int has_duplicate_addr(struct sockaddr *addr, const addr_record_t *record
 	return false;
 }
 
+#if !defined(_WIN32) && defined(NO_IFADDRS)
+// Helper function to get the IPv6 address of the default interface
+static int get_local_default_inet6(uint16_t port, struct sockaddr_in6 *result) {
+	const char *dummy_host = "2001:db8::1"; // dummy public unreachable address
+	const uint16_t dummy_port = 9;          // discard port
+
+	struct sockaddr_in6 sin6;
+	memset(&sin6, 0, sizeof(sin6));
+	sin6.sin6_family = AF_INET6;
+	sin6.sin6_port = htons(dummy_port);
+	if (inet_pton(AF_INET6, dummy_host, &sin6.sin6_addr) != 1)
+		return -1;
+
+	socket_t sock = socket(AF_INET6, SOCK_DGRAM, IPPROTO_UDP);
+	if (sock == INVALID_SOCKET)
+		return -1;
+
+	if (connect(sock, (const struct sockaddr *)&sin6, sizeof(sin6)))
+		goto error;
+
+	socklen_t result_len = sizeof(*result);
+	if (getsockname(sock, (struct sockaddr *)result, &result_len))
+		goto error;
+
+	if (result_len != sizeof(*result))
+		goto error;
+
+	addr_set_port((struct sockaddr *)result, port);
+	closesocket(sock);
+	return 0;
+
+error:
+	closesocket(sock);
+	return -1;
+}
+#endif
+
 int udp_get_addrs(socket_t sock, addr_record_t *records, size_t count) {
 	addr_record_t bound;
 	if (udp_get_bound_addr(sock, &bound) < 0) {
@@ -417,8 +454,9 @@ int udp_get_addrs(socket_t sock, addr_record_t *records, size_t count) {
 	// specification [RFC6724] specifies that temporary addresses [RFC4941] are to be preferred
 	// over permanent addresses.
 
-	// Here, we will prevent gathering permanent IPv6 addresses if a temporary one is found.
-	// This is more restrictive but fully compliant.
+	// IPv6 IIDs generated by modern systems are opaque so there is no way to reliably differentiate
+	// privacy-enabled IPv6 addresses here. Therefore, we hope the preferred addresses are listed
+	// first, and we never list link-local addresses.
 
 	addr_record_t *current = records;
 	addr_record_t *end = records + count;
@@ -452,23 +490,12 @@ int udp_get_addrs(socket_t sock, addr_record_t *records, size_t count) {
 	}
 
 	SOCKET_ADDRESS_LIST *list = (SOCKET_ADDRESS_LIST *)buf;
-
-	bool has_temp_inet6 = false;
-	for (int i = 0; i < list->iAddressCount; ++i) {
-		struct sockaddr *sa = list->Address[i].lpSockaddr;
-		if (addr_is_temp_inet6(sa)) {
-			has_temp_inet6 = true;
-			break;
-		}
-	}
-
 	for (int i = 0; i < list->iAddressCount; ++i) {
 		struct sockaddr *sa = list->Address[i].lpSockaddr;
 		socklen_t len = list->Address[i].iSockaddrLength;
 		if ((sa->sa_family == AF_INET ||
 		     (sa->sa_family == AF_INET6 && bound.addr.ss_family == AF_INET6)) &&
-		    !addr_is_local(sa) &&
-		    !(has_temp_inet6 && sa->sa_family == AF_INET6 && !addr_is_temp_inet6(sa))) {
+		    !addr_is_local(sa)) {
 			if (!has_duplicate_addr(sa, records, current - records)) {
 				++ret;
 				if (current != end) {
@@ -489,20 +516,6 @@ int udp_get_addrs(socket_t sock, addr_record_t *records, size_t count) {
 		return -1;
 	}
 
-	bool has_temp_inet6 = false;
-	for (struct ifaddrs *ifa = ifas; ifa; ifa = ifa->ifa_next) {
-		unsigned int flags = ifa->ifa_flags;
-		if (!(flags & IFF_UP) || (flags & IFF_LOOPBACK))
-			continue;
-		if (strcmp(ifa->ifa_name, "docker0") == 0)
-			continue;
-
-		if (ifa->ifa_addr && addr_is_temp_inet6(ifa->ifa_addr)) {
-			has_temp_inet6 = true;
-			break;
-		}
-	}
-
 	for (struct ifaddrs *ifa = ifas; ifa; ifa = ifa->ifa_next) {
 		unsigned int flags = ifa->ifa_flags;
 		if (!(flags & IFF_UP) || (flags & IFF_LOOPBACK))
@@ -515,9 +528,7 @@ int udp_get_addrs(socket_t sock, addr_record_t *records, size_t count) {
 		if (sa &&
 		    (sa->sa_family == AF_INET ||
 		     (sa->sa_family == AF_INET6 && bound.addr.ss_family == AF_INET6)) &&
-		    !addr_is_local(sa) &&
-		    !(has_temp_inet6 && sa->sa_family == AF_INET6 && !addr_is_temp_inet6(sa)) &&
-		    (len = addr_get_len(sa)) > 0) {
+		    !addr_is_local(sa) && (len = addr_get_len(sa)) > 0) {
 			if (!has_duplicate_addr(sa, records, current - records)) {
 				++ret;
 				if (current != end) {
@@ -544,17 +555,23 @@ int udp_get_addrs(socket_t sock, addr_record_t *records, size_t count) {
 		return -1;
 	}
 
+	bool ifconf_has_inet6 = false;
 	int n = ifc.ifc_len / sizeof(struct ifreq);
 	for (int i = 0; i < n; ++i) {
 		struct ifreq *ifr = ifc.ifc_req + i;
 		struct sockaddr *sa = &ifr->ifr_addr;
-		if (sa->sa_family == AF_INET && !addr_is_local(sa)) {
-			struct sockaddr_in *sin = (struct sockaddr_in *)&ifr->ifr_addr;
+		if (sa->sa_family == AF_INET6)
+			ifconf_has_inet6 = true;
+
+		socklen_t len;
+		if ((sa->sa_family == AF_INET ||
+		     (sa->sa_family == AF_INET6 && bound.addr.ss_family == AF_INET6)) &&
+		    !addr_is_local(sa) && (len = addr_get_len(sa)) > 0) {
 			if (!has_duplicate_addr(sa, records, current - records)) {
 				++ret;
 				if (current != end) {
-					memcpy(&current->addr, sin, sizeof(*sin));
-					current->len = sizeof(*sin);
+					memcpy(&current->addr, sa, len);
+					current->len = len;
 					addr_set_port((struct sockaddr *)&current->addr, port);
 					++current;
 				}
@@ -562,43 +579,17 @@ int udp_get_addrs(socket_t sock, addr_record_t *records, size_t count) {
 		}
 	}
 
-	if (bound.addr.ss_family == AF_INET6) {
-		char hostname[HOST_NAME_MAX];
-		if (gethostname(hostname, HOST_NAME_MAX))
-			strcpy(hostname, "localhost");
-
-		char service[8];
-		snprintf(service, 8, "%hu", port);
-
-		struct addrinfo *ai_list = NULL;
-		struct addrinfo hints;
-		memset(&hints, 0, sizeof(hints));
-		hints.ai_family = AF_INET6;
-		hints.ai_socktype = SOCK_DGRAM;
-		hints.ai_protocol = 0;
-		hints.ai_flags = AI_ADDRCONFIG | AI_NUMERICSERV;
-		if (getaddrinfo(hostname, service, &hints, &ai_list) == 0) {
-			bool has_temp_inet6 = false;
-			for (struct addrinfo *ai = ai_list; ai; ai = ai->ai_next) {
-				if (addr_is_temp_inet6(ai->ai_addr)) {
-					has_temp_inet6 = true;
-					break;
+	if (!ifconf_has_inet6 && bound.addr.ss_family == AF_INET6) {
+		struct sockaddr_in6 sin6;
+		if (get_local_default_inet6(port, &sin6) == 0) {
+			if (!addr_is_local((const struct sockaddr *)&sin6)) {
+				++ret;
+				if (current != end) {
+					memcpy(&current->addr, &sin6, sizeof(sin6));
+					current->len = sizeof(sin6);
+					++current;
 				}
 			}
-			for (struct addrinfo *ai = ai_list; ai; ai = ai->ai_next) {
-				if (!addr_is_local(ai->ai_addr) &&
-				    !(has_temp_inet6 && !addr_is_temp_inet6(ai->ai_addr))) {
-					if (!has_duplicate_addr(ai->ai_addr, records, current - records)) {
-						++ret;
-						if (current != end) {
-							memcpy(&current->addr, ai->ai_addr, ai->ai_addrlen);
-							current->len = ai->ai_addrlen;
-							++current;
-						}
-					}
-				}
-			}
-			freeaddrinfo(ai_list);
 		}
 	}
 #endif
